# Inference

## Training algorithms

::: sbi.inference.trainers.npe.npe_a.NPE_A
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.npe.npe_c.NPE_C
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.fmpe.fmpe.FMPE
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.npse.npse.NPSE
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.nle.nle_a.NLE_A
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.nre.nre_a.NRE_A
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.nre.nre_b.NRE_B
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.nre.nre_c.NRE_C
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.trainers.nre.bnre.BNRE
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.abc.mcabc.MCABC
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.abc.smcabc.SMCABC
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

## Helpers

::: sbi.inference.trainers.base.simulate_for_sbi

::: sbi.utils.user_input_checks.process_prior

::: sbi.utils.user_input_checks.process_simulator
